from Tarski import TarskiBoard
from Tarski import TarskiObject
from predicates import cube
from predicates import dodec
from predicates import tet
from predicates import small
from predicates import medium
from predicates import large
from predicates import sameShape
from predicates import sameSize
from predicates import sameCol
from predicates import sameRow
from predicates import smaller
from predicates import larger
from predicates import leftOf
from predicates import rightOf
from predicates import frontOf
from predicates import backOf
from predicates import between
from predicates import adjoins